@@ -1,11 +1,26 @@
-/* Go to date dialog for Evolution
+/*
+ * Go to date dialog for Evolution
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Federico Mena <federico@ximian.com>
+ *      JP Rosevear <jpr@ximian.com>
  *
- * Copyright (C) 1998 Red Hat, Inc.
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Federico Mena <federico@ximian.com>
- *          JP Rosevear <jpr@ximian.com>
  */
 
 #include <config.h>
