@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2004 Ximian, Inc. (www.ximian.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -27,15 +27,8 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <glib.h>
-
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkalignment.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include <libgnomeui/gnome-druid.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
@@ -43,8 +36,6 @@
 
 #include "e-config.h"
 
-#include <e-util/e-icon-factory.h>
-
 #include <glib/gi18n.h>
 
 #define d(x)
@@ -132,6 +123,10 @@ ep_finalise(GObject *o)
 	}
 
 	while ( (wn = (struct _widget_node *)e_dlist_remhead(&p->widgets)) ) {
+		/* disconnect the gtk_widget_destroyed function from the widget */
+		if (wn->widget)
+			g_signal_handlers_disconnect_matched (wn->widget, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, &wn->widget);
+
 		g_free(wn);
 	}
 
@@ -428,10 +423,14 @@ ec_rebuild(EConfig *emp)
 
 	for (wn = (struct _widget_node *)p->widgets.head;wn->next;wn=wn->next) {
 		struct _EConfigItem *item = wn->item;
+		const gchar *translated_label = NULL;
 		GtkWidget *w;
 
 		d(printf(" '%s'\n", item->path));
 
+		if (item->label != NULL)
+			translated_label = gettext (item->label);
+
 		/* If the last section doesn't contain anything, hide it */
 		if (sectionnode != NULL
 		    && sectionnode->frame != NULL
@@ -530,7 +529,7 @@ ec_rebuild(EConfig *emp)
 				} else {
 					page = gnome_druid_page_edge_new(item->type == E_CONFIG_PAGE_START?GNOME_EDGE_START:GNOME_EDGE_FINISH);
 					gtk_widget_show(page);
-					gnome_druid_page_edge_set_title((GnomeDruidPageEdge *)page, item->label);
+					gnome_druid_page_edge_set_title((GnomeDruidPageEdge *)page, translated_label);
 					gnome_druid_insert_page((GnomeDruid *)druid, pagenode?(GnomeDruidPage *)pagenode->frame:NULL, (GnomeDruidPage *)page);
 				}
 				if (item->type == E_CONFIG_PAGE_FINISH) {
@@ -585,13 +584,13 @@ ec_rebuild(EConfig *emp)
 				if (emp->type == E_CONFIG_DRUID) {
 					w = gnome_druid_page_standard_new();
 					gtk_widget_show(w);
-					gnome_druid_page_standard_set_title((GnomeDruidPageStandard *)w, item->label);
+					gnome_druid_page_standard_set_title((GnomeDruidPageStandard *)w, translated_label);
 					gnome_druid_insert_page((GnomeDruid *)druid, pagenode?(GnomeDruidPage *)pagenode->frame:NULL, (GnomeDruidPage *)w);
 					wn->frame = w;
 					page = ((GnomeDruidPageStandard *)w)->vbox;
 					connect = TRUE;
 				} else {
-					w = gtk_label_new_with_mnemonic (item->label);
+					w = gtk_label_new_with_mnemonic (translated_label);
 					gtk_widget_show(w);
 					page = gtk_vbox_new(FALSE, 12);
 					gtk_container_set_border_width((GtkContainer *)page, 12);
@@ -659,8 +658,8 @@ ec_rebuild(EConfig *emp)
 					wn->frame = NULL;
 				}
 
-				if (item->label) {
-					char *txt = g_strdup_printf("<span weight=\"bold\">%s</span>", item->label);
+				if (translated_label != NULL) {
+					char *txt = g_strdup_printf("<span weight=\"bold\">%s</span>", translated_label);
 
 					label = g_object_new(gtk_label_get_type(),
 							     "label", txt,
