@@ -1,26 +1,27 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2002 Ximian Inc.
- *
- *  Authors: Not Zed <notzed@lostzed.mmc.com.au>
- *           Jeffrey Stedfast <fejj@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Not Zed <notzed@lostzed.mmc.com.au>
+ *      Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-
 #ifndef _RULE_CONTEXT_H
 #define _RULE_CONTEXT_H
 
@@ -50,14 +51,14 @@ enum {
 struct _RuleContext {
 	GObject parent_object;
 	struct _RuleContextPrivate *priv;
-	
+
 	char *error;              /* string version of error */
 
 	guint32 flags;		/* capability flags */
 
 	GList *parts;
 	GList *rules;
-	
+
 	GHashTable *part_set_map; /* map set types to part types */
 	GList *part_set_list;
 	GHashTable *rule_set_map; /* map set types to rule types */
@@ -73,12 +74,12 @@ struct _RuleContextClass {
 	int (*load) (RuleContext *rc, const char *system, const char *user);
 	int (*save) (RuleContext *rc, const char *user);
 	int (*revert) (RuleContext *rc, const char *user);
-	
+
 	GList *(*delete_uri) (RuleContext *rc, const char *uri, GCompareFunc cmp);
 	GList *(*rename_uri) (RuleContext *rc, const char *olduri, const char *newuri, GCompareFunc cmp);
 
 	FilterElement *(*new_element)(RuleContext *rc, const char *name);
-	
+
 	/* signals */
 	void (*rule_added) (RuleContext *rc, FilterRule *rule);
 	void (*rule_removed) (RuleContext *rc, FilterRule *rule);
