@@ -1,65 +1,44 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* The following is the mozilla license blurb, as the bodies some of
+   these functions were derived from the mozilla source. */
 /*
- *  Authors: Chris Toshok <toshok@ximian.com>
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
- *  Copyright (C) 2003 Novell, Inc. (www.novell.com)
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- */
-
-/* this code is pretty much cut&pasted and renamed from mozilla.
-   here's their copyright/blurb */
-
-/*
- * The contents of this file are subject to the Mozilla Public
- * License Version 1.1 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- * 
- * Software distributed under the License is distributed on an "AS
- * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
- * implied. See the License for the specific language governing
- * rights and limitations under the License.
- * 
  * The Original Code is the Netscape security libraries.
- * 
- * The Initial Developer of the Original Code is Netscape
- * Communications Corporation.  Portions created by Netscape are 
- * Copyright (C) 2000 Netscape Communications Corporation.  All
- * Rights Reserved.
- * 
- * Contributor(s):
- *  Ian McGreer <mcgreer@netscape.com>
- *  Javier Delgadillo <javi@netscape.com>
- * 
- * Alternatively, the contents of this file may be used under the
- * terms of the GNU General Public License Version 2 or later (the
- * "GPL"), in which case the provisions of the GPL are applicable 
- * instead of those above.  If you wish to allow use of your 
- * version of this file only under the terms of the GPL and not to
- * allow others to use your version of this file under the MPL,
- * indicate your decision by deleting the provisions above and
- * replace them with the notice and other provisions required by
- * the GPL.  If you do not delete the provisions above, a recipient
- * may use your version of this file under either the MPL or the
- * GPL.
  *
+ * The Initial Developer of the Original Code is
+ * Netscape Communications Corporation.
+ * Portions created by the Initial Developer are Copyright (C) 1994-2000
+ * the Initial Developer. All Rights Reserved.
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  */
 
-
+/*
+ * Author: Chris Toshok (toshok@ximian.com)
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -74,8 +53,8 @@ e_cert_trust_init (CERTCertTrust *trust)
 
 void
 e_cert_trust_init_with_values (CERTCertTrust *trust,
-			       unsigned int ssl, 
-			       unsigned int email, 
+			       unsigned int ssl,
+			       unsigned int email,
 			       unsigned int objsign)
 {
   memset(trust, 0, sizeof(CERTCertTrust));
@@ -90,7 +69,7 @@ e_cert_trust_copy (CERTCertTrust *trust, CERTCertTrust *t)
   if (t)
     memcpy(trust, t, sizeof(CERTCertTrust));
   else
-    memset(trust, 0, sizeof(CERTCertTrust)); 
+    memset(trust, 0, sizeof(CERTCertTrust));
 }
 
 void
@@ -241,7 +220,7 @@ e_cert_trust_set_trusted_ca (CERTCertTrust *trust)
 				  PR_FALSE, PR_FALSE);
 }
 
-void 
+void
 e_cert_trust_set_valid_peer (CERTCertTrust *trust)
 {
   e_cert_trust_set_ssl_trust (trust,
@@ -258,7 +237,7 @@ e_cert_trust_set_valid_peer (CERTCertTrust *trust)
 				  PR_FALSE, PR_FALSE);
 }
 
-void 
+void
 e_cert_trust_set_valid_server_peer (CERTCertTrust *trust)
 {
   e_cert_trust_set_ssl_trust (trust,
@@ -275,7 +254,7 @@ e_cert_trust_set_valid_server_peer (CERTCertTrust *trust)
 				  PR_FALSE, PR_FALSE);
 }
 
-void 
+void
 e_cert_trust_set_trusted_peer (CERTCertTrust *trust)
 {
   e_cert_trust_set_ssl_trust (trust,
@@ -321,8 +300,8 @@ e_cert_trust_has_any_ca (CERTCertTrust *trust)
 
 PRBool
 e_cert_trust_has_ca (CERTCertTrust *trust,
-		     PRBool checkSSL, 
-		     PRBool checkEmail,  
+		     PRBool checkSSL,
+		     PRBool checkEmail,
 		     PRBool checkObjSign)
 {
   if (checkSSL && !e_cert_trust_has_trust(trust->sslFlags, CERTDB_VALID_CA))
@@ -336,8 +315,8 @@ e_cert_trust_has_ca (CERTCertTrust *trust,
 
 PRBool
 e_cert_trust_has_peer (CERTCertTrust *trust,
-		       PRBool checkSSL, 
-		       PRBool checkEmail,  
+		       PRBool checkSSL,
+		       PRBool checkEmail,
 		       PRBool checkObjSign)
 {
   if (checkSSL && !e_cert_trust_has_trust(trust->sslFlags, CERTDB_VALID_PEER))
@@ -361,8 +340,8 @@ e_cert_trust_has_any_user (CERTCertTrust *trust)
 
 PRBool
 e_cert_trust_has_user (CERTCertTrust *trust,
-		       PRBool checkSSL, 
-		       PRBool checkEmail,  
+		       PRBool checkSSL,
+		       PRBool checkEmail,
 		       PRBool checkObjSign)
 {
   if (checkSSL && !e_cert_trust_has_trust(trust->sslFlags, CERTDB_USER))
@@ -376,8 +355,8 @@ e_cert_trust_has_user (CERTCertTrust *trust,
 
 PRBool
 e_cert_trust_has_trusted_ca (CERTCertTrust *trust,
-			     PRBool checkSSL, 
-			     PRBool checkEmail,  
+			     PRBool checkSSL,
+			     PRBool checkEmail,
 			     PRBool checkObjSign)
 {
   if (checkSSL && !(e_cert_trust_has_trust(trust->sslFlags, CERTDB_TRUSTED_CA) ||
@@ -386,7 +365,7 @@ e_cert_trust_has_trusted_ca (CERTCertTrust *trust,
   if (checkEmail && !(e_cert_trust_has_trust(trust->emailFlags, CERTDB_TRUSTED_CA) ||
                       e_cert_trust_has_trust(trust->emailFlags, CERTDB_TRUSTED_CLIENT_CA)))
     return PR_FALSE;
-  if (checkObjSign && 
+  if (checkObjSign &&
        !(e_cert_trust_has_trust(trust->objectSigningFlags, CERTDB_TRUSTED_CA) ||
          e_cert_trust_has_trust(trust->objectSigningFlags, CERTDB_TRUSTED_CLIENT_CA)))
     return PR_FALSE;
@@ -395,15 +374,15 @@ e_cert_trust_has_trusted_ca (CERTCertTrust *trust,
 
 PRBool
 e_cert_trust_has_trusted_peer (CERTCertTrust *trust,
-			       PRBool checkSSL, 
-			       PRBool checkEmail,  
+			       PRBool checkSSL,
+			       PRBool checkEmail,
 			       PRBool checkObjSign)
 {
   if (checkSSL && !(e_cert_trust_has_trust(trust->sslFlags, CERTDB_TRUSTED)))
     return PR_FALSE;
   if (checkEmail && !(e_cert_trust_has_trust(trust->emailFlags, CERTDB_TRUSTED)))
     return PR_FALSE;
-  if (checkObjSign && 
+  if (checkObjSign &&
        !(e_cert_trust_has_trust(trust->objectSigningFlags, CERTDB_TRUSTED)))
     return PR_FALSE;
   return PR_TRUE;
